--
-- InsertSokuon.lua
-- 「っ」を挿入するだけ
--
-- Copyright (C) 2012 ちょむＰ/VOCALOMAKETS
--

--
-- プラグインマニフェスト関数.
--
function manifest()
    myManifest = {
        name          = "InsertSokuon",
        comment       = "「っ」を挿入するだけ",
        author        = "ちょむＰ/VOCALOMAKETS",
        pluginID      = "{8a6da608-999d-4c32-ad5e-9af17168f698}",
        pluginVersion = "1.0.0.1",
        apiVersion    = "3.0.0.1"
    }
    return myManifest
end

-- スクリプトのエントリポイント関数.
--
function main(processParam, envParam)
	
	-- 終了コード
	local endStatus = 0
	-- ノートの高さの初期値
	local noteTone = 72
	-- 挿入ノートの長さ(1/32音符)
	local newNoteDur = 60
	
	-- 実行時に渡された処理条件パラメータを取得します.
	local songPosTick = processParam.songPosTick -- 現在のカーソル位置
	
	-- ソングポジションに重なっているノートをスキャンします
	
	-- ノートリスト先頭に位置づける
	VSSeekToBeginNote()
	
	-- 先頭ノート取得
	local retCode, note = VSGetNextNoteEx()
	while ( retCode == 1 ) do
		
		-- ソングポジションを越しちゃったら
		if ( songPosTick < note.posTick ) then
			-- カーソル位置から次のノートまでの距離で挿入ノートの長さを調整
			newNoteDur = (note.posTick - songPosTick)
			if ( newNoteDur > 60 ) then 
				newNoteDur = 60
			end
			-- ループ脱出
			break
		end
		
		-- ノートの高さを記憶しておきます
		noteTone = note.noteNum
		
		-- 同時刻にノートが存在している場合は削除してループ脱出
		if ( note.posTick == songPosTick ) then
			retCode = VSRemoveNote(note)
			if (retCode ~= 1 ) then
				endStatus = 1
				VSMessageBox("ノートの削除に失敗",0)
				break
			end
			break
		end
		
		-- ノートがカーソル位置をまたいでいる場合は
		-- 長さを調整
		if ( note.posTick < songPosTick and songPosTick < note.posTick + note.durTick) then
			note.durTick = (songPosTick - note.posTick)
			retCode = VSUpdateNoteEx(note)
			if (retCode ~= 1 ) then
				endStatus = 1
				VSMessageBox("ノートの更新に失敗",0)
				break
			end
			break
		end
		
		-- 次のノートを取得する
		retCode, note = VSGetNextNoteEx()
	end

	-- ノート追加処理
	local newNote = {
		posTick			= songPosTick,
		durTick			= newNoteDur,
		noteNum			= noteTone,
		velocity		= 64,
		lyric			= "っ",
		phonemes		= "Sil",
		phLock			= 0, -- VS_FALSE
		bendDepth		= 0,
		bendLength		= 0,
		risePort		= 0, -- VS_FALSE
		fallPort		= 0, -- VS_FALSE
		decay			= 50,
		accent			= 50,
		opening			= 127,
		vibratoLength	= 0,
		vibratoType		= 0
	}
	retCode = VSInsertNoteEx(newNote)
	if (retCode ~= 1 ) then
		endStatus = 1
		VSMessageBox("ノートの挿入に失敗",0)
	end
	
	return endStatus
end
